import java.awt.*;
import java.awt.event.*;


class AnimDemo1 extends Canvas implements Runnable
{
  static final int WIDTH  = 450;
  static final int HEIGHT = 300;
  static final int BALL_SIZE = 20;
  static final int ANIM_DELAY = 20;

  int ball_xpos  = 10;
  int ball_ypos  = 10;
  int ball_dx    = 4;
  int ball_dy    = 4;
  int ball_xsign = 1;
  int ball_ysign = 1;

  Image back_image; // the background image

  public AnimDemo1()
  {
    back_image = getToolkit().getImage("background.jpg");

    // wait for image to load . . .
    try {
      MediaTracker tracker = new MediaTracker(this);
      tracker.addImage(back_image, 0);
      tracker.waitForID(0);
    } catch (Exception e) { System.exit(0); }

     // start animation
    this.start();
  }

  /*
   * We'd like to be WIDTHxHEIGHT large, please
   */
  public Dimension getPreferredSize()
  {
    return new Dimension( WIDTH, HEIGHT );
  }

  /*
   * Draw ourselves
   */
  public void paint( Graphics g )
  {
    // draw background
    g.drawImage( back_image,0,0,this.getWidth(),this.getHeight(),this );

    // draw ball
    g.setColor( Color.red );
    g.fillOval( ball_xpos, ball_ypos, BALL_SIZE, BALL_SIZE );
    g.setColor( Color.black );
    g.drawOval( ball_xpos, ball_ypos, BALL_SIZE, BALL_SIZE );
  }

  long last_update; // time of last call to update()

  public void update( Graphics g )
  {
    // just let paint() do the drawing
    paint(g);

    // dodgy frames per second hack
    long curr_time=System.currentTimeMillis();
    g.setColor( Color.white );
    g.drawString( Integer.toString((int)(1000/(curr_time-last_update))),10,10 );
    last_update=curr_time;
  }

  /*
   * do the animation
   */
  public void run()
  {
    long t = System.currentTimeMillis();

    /* loop forever (until interrupted) */
    while( true )
    {
      /* calculate new ball position */
      ball_xpos += (ball_dx * ball_xsign );
      ball_ypos += (ball_dy * ball_ysign );

      if( ball_xpos <= 0 ) ball_xsign=1;
      else if( ball_xpos >= getWidth() - BALL_SIZE ) ball_xsign=-1;
      if( ball_ypos <= 0 ) ball_ysign=1;
      else if( ball_ypos >= getHeight() - BALL_SIZE ) ball_ysign=-1;

      /* send redraw message */
      repaint();

      try
      {
        t += ANIM_DELAY;
        Thread.sleep( Math.max( 0, t - System.currentTimeMillis() ) );
      }
      catch( InterruptedException e ) { break; }
    } /* while */
  }

  /*
   * start animation thread
   */
  public void start()
  {
    new Thread(this).start();
  }

  /*
   * Demo application
   */
  public static void main( String args[] )
  {
    Frame win = new Frame( "AnimDemo1" );

    win.addWindowListener( new WindowAdapter()
                           {
                             public void windowClosing(java.awt.event.WindowEvent e)
                             {
                               System.exit(0);
                             }
                           } );
    win.add( new AnimDemo1() );
    win.pack();
    win.show();
  }
}
