/*
 * SineTable
 *
 * Simple hack to precalculate a table of sine values
 * Use for harmonic motion, etc . . .
 */

public class SineTable
{
  private int table[];

  /*
   * Constructor
   *
   * size - peak to peak size of the wave (typically the
   *        peak to peak size of the motion in pixels)
   * no_of_steps - how fine-grained is the sampling of the
   *               wave (i.e., how large is the table)
   */
  public SineTable( int size, int no_of_steps )
  {
    table = new int[no_of_steps];

    for(int i=0; i<table.length; i++)
      table[i] = size - (int) (0.5*size*(Math.cos(2*Math.PI*i/no_of_steps)+ 1));
  }

  /*
   * get()
   *
   * Retrieve a value from our sine table
   * Declared final to allow compiler to inline
   */
  public final int get( int step )
  {
    return table[ step ];
  }

  /*
   * length()
   *
   * Get size of table
   * Declared final to allow compiler to inline
   */
  public final int length()
  {
    return table.length;
  }
}